@@ -12,19 +12,17 @@ instruction:
 ```yaml
 ::: some.identifier
     handler: python
-    selection:
+    options:
       option1: value1
       option2:
-        - value2a
-        - value2b
-    rendering:
+      - value2a
+      - value2b
       option_x: etc
 ```
 """
 
 from __future__ import annotations
 
-import functools
 import re
 from collections import ChainMap
 from typing import TYPE_CHECKING, Any, MutableSequence
@@ -133,19 +131,35 @@ class AutoDocProcessor(BlockProcessor):
             el.extend(headings)
 
             page = self._autorefs.current_page
-            if page:
+            if page is not None:
                 for heading in headings:
-                    anchor = heading.attrib["id"]
-                    self._autorefs.register_anchor(page, anchor)
+                    rendered_anchor = heading.attrib["id"]
+                    self._autorefs.register_anchor(page, rendered_anchor)
 
                     if "data-role" in heading.attrib:
                         self._handlers.inventory.register(
-                            name=anchor,
+                            name=rendered_anchor,
                             domain=handler.domain,
                             role=heading.attrib["data-role"],
-                            uri=f"{page}#{anchor}",
+                            priority=1,  # register with standard priority
+                            uri=f"{page}#{rendered_anchor}",
                         )
 
+                        # also register other anchors for this object in the inventory
+                        try:
+                            data_object = handler.collect(rendered_anchor, handler.fallback_config)
+                        except CollectionError:
+                            continue
+                        for anchor in handler.get_anchors(data_object):
+                            if anchor not in self._handlers.inventory:
+                                self._handlers.inventory.register(
+                                    name=anchor,
+                                    domain=handler.domain,
+                                    role=heading.attrib["data-role"],
+                                    priority=2,  # register with lower priority
+                                    uri=f"{page}#{rendered_anchor}",
+                                )
+
             parent.append(el)
 
         if the_rest:
@@ -183,13 +197,7 @@ class AutoDocProcessor(BlockProcessor):
 
         global_options = handler_config.get("options", {})
         local_options = config.get("options", {})
-        deprecated_global_options = ChainMap(handler_config.get("selection", {}), handler_config.get("rendering", {}))
-        deprecated_local_options = ChainMap(config.get("selection", {}), config.get("rendering", {}))
-
-        options = ChainMap(local_options, deprecated_local_options, global_options, deprecated_global_options)
-
-        if deprecated_global_options or deprecated_local_options:
-            self._warn_about_options_key()
+        options = ChainMap(local_options, global_options)
 
         if heading_level:
             options = ChainMap(options, {"heading_level": heading_level})  # like setdefault
@@ -199,12 +207,12 @@ class AutoDocProcessor(BlockProcessor):
             data: CollectorItem = handler.collect(identifier, options)
         except CollectionError as exception:
             log.error(str(exception))  # noqa: TRY400
-            if PluginError is SystemExit:  # When MkDocs 1.2 is sufficiently common, this can be dropped.
+            if PluginError is SystemExit:  # TODO: when MkDocs 1.2 is sufficiently common, this can be dropped.
                 log.error(f"Error reading page '{self._autorefs.current_page}':")  # noqa: TRY400
             raise PluginError(f"Could not collect '{identifier}'") from exception
 
         if handler_name not in self._updated_envs:  # We haven't seen this handler before on this document.
-            log.debug("Updating renderer's env")
+            log.debug("Updating handler's rendering env")
             handler._update_env(self.md, self._config)
             self._updated_envs.add(handler_name)
 
@@ -220,11 +228,6 @@ class AutoDocProcessor(BlockProcessor):
 
         return rendered, handler, data
 
-    @classmethod
-    @functools.lru_cache(maxsize=None)  # Warn only once
-    def _warn_about_options_key(cls) -> None:
-        log.info("DEPRECATION: 'selection' and 'rendering' are deprecated and merged into a single 'options' YAML key")
-
 
 class _PostProcessor(Treeprocessor):
     def run(self, root: Element) -> None:
